#
# spec file for package semantik
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           semantik
Version:        1.2.8
Release:        bp155.2.5
Summary:        A mindmapping-like tool
License:        GPL-2.0-only AND GPL-3.0-only
Group:          Productivity/Office/Other
URL:            https://waf.io/semantik.html
Source0:        https://waf.io/%{name}-%{version}.tar.bz2
Source1:        %{name}.1
BuildRequires:  ImageMagick
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  kdelibs4support-devel
BuildRequires:  ki18n-devel
BuildRequires:  kiconthemes-devel
BuildRequires:  kio-devel
BuildRequires:  libqt5-linguist
BuildRequires:  libqt5-qtdeclarative-devel
BuildRequires:  libqt5-qtsvg-devel
BuildRequires:  libqt5-qtwebengine-devel
BuildRequires:  python3-Pygments
BuildRequires:  python3-devel
BuildRequires:  update-desktop-files

%description
Semantik (previously Kdissert) is a mindmapping-like tool to help students
to produce complicated documents very quickly and efficiently :
presentations, dissertations, thesis, reports.

While targetted mostly at students, Semantik can also help teachers,
decision maker, engineers and businessmen.

Though this application shares some similarities with general-purpose
mindmapping tools like Freemind or Vym, the very first goal of Semantik is
to create general-purpose documents through the use of mindmaps.

%prep
%setup -q

#wrong-icon-size
convert -strip src/data/hi48-app-semantik-d.png -resize 48x48 src/data/hi48-app-semantik-d.png
#env-script-interpreter
for i in src/filters/*.py src/sembind.py waf; do
  sed -i '1s:.*:#!/usr/bin/python3:' $i;
done

%build

export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"

./waf configure \
      --prefix=%{_prefix} \
      --python=%{_bindir}/python3

./waf build %{?_smp_mflags}

%install
./waf install --destdir=%{buildroot}
install -Dm0644 src/data/%{name}.svg %{buildroot}%{_datadir}/pixmaps/%{name}.svg
install -m0644 src/data/%{name}-d.svg %{buildroot}%{_datadir}/pixmaps/%{name}-d.svg
%suse_update_desktop_file -i %{name} Office ProjectManagement
%suse_update_desktop_file -i %{name}-d Office ProjectManagement
%find_lang %{name} --all-name
%fdupes %{buildroot}

# fix non-executable-script
chmod a+rx %{buildroot}%{_datadir}/semantik/templates/pdflatex/wscript
chmod a+rx %{buildroot}%{_datadir}/semantik/templates/beamer/wscript
chmod a+rx %{buildroot}%{_datadir}/semantik/templates/waf
chmod a+rx %{buildroot}%{_datadir}/semantik/filters/*.py
chmod a+rx %{buildroot}%{_datadir}/semantik/sembind.py

#fix shebang
sed -i -e 's|#! %{_bindir}/python|#!%{_bindir}/python3|' %{buildroot}%{_datadir}/semantik/templates/pdflatex/wscript
sed -i -e 's|#! %{_bindir}/python|#!%{_bindir}/python3|' %{buildroot}%{_datadir}/semantik/templates/beamer/wscript

# install man page
install -D -m644 %{SOURCE1} %{buildroot}%{_mandir}/man1/%{name}.1

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files -f %{name}.lang
%license LICENSE
%doc ChangeLog README
%{_bindir}/semantik*
%{_libdir}/lib*.so*
%{_datadir}/applications/semantik*.desktop
%{_datadir}/pixmaps/*.svg
%{_datadir}/icons/hicolor/*/apps/semantik*.svg
%{_datadir}/mime/packages/%{name}.xml
%{_mandir}/man1/%{name}.1*
%{_datadir}/semantik
%{_kf5_kxmlguidir}/semantik*

%changelog
* Tue Apr 18 2023 Max Lin <mlin@suse.com>
- Use python3 as the script interpreter in wscript file
* Sat Jun 25 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to 1.2.8
  * Improve boundaries and cloud elements
  * Add and edit newlines in diagram elements #119
  * Deselect items before exporting images #113
  * Add a Markdown export filter (experimental) #110
  * Update waf to 2.0.24 and improve the build on Ubuntu Jammy
* Thu Jun 24 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 1.2.7
  * Fix the rendering of activity elements start/end
  * Fix saving empty documents
  * Improve the layout for various diagram elements
  * Hide top-right corner data flags on empty map items
  * Workaround for dark desktop color schemes
  * Improve the zoom system
- Remove _service file, update can be done with
  "osc service ra download_files"
* Wed Mar 25 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.2.4
  * Eliminate drawing artifacts
  * Eliminate grid alignment issues on diagrams
  * Improve label positioning on diagrams
  * Italian translations
  * Fix stale connections when disconnecting multiple references
  * Fix broken flags #98
  * Fix shortcuts configurability #96
  * Fix diagram thumbnail display on item selection
  * Add 'nocaption' to disable picture captions in LaTeX
  * Add 'disable_row_header' and 'disable_col_header' to improve
    table exports
  * Add 'disable_slide' to limit extra Beamer slides
  * Paint long branches with a lighter color
* Wed Feb  6 2019 Marguerite Su <i@marguerite.su>
- set _service to disabled, it's a factory package
* Sun Jan  6 2019 lars@linux-schulserver.de
- update to 1.2.1:
  * Fix duplicate reference values
  * Fix double prompts for overwriting files
  * Fix map variables visibility when opening maps
  * Fix document generator dialog's tab navigation
  * Fix boundary objects' text alignment (diagrams)
  * Fix pipe objects' resizing (diagrams)
  * Fix component objects' margin sizes
  * Enable newlines on most diagram objects #89
  * Add global settings for commands to execute after a template is called
  From Semantik 1.2.0:
  * Add support for references (Kdissert) #91
  * Add support for newlines in table attachments #89
  * Configure arrow colors on the main map
  * Add a new Entity shape for data modeling (diagrams)
  * Fix missing crossing lines when printing or exporting diagrams
  From Semantik 1.1.0:
  * Improve the looks of diagram crossing lines
  From Semantik 1.0.9:
  * Display picture and diagram thumbnails on the main map
  * Add a touchpad mode for laptop users
  From Semantik 1.0.8:
  * Add new formatting actions to the Rich Text editor: text color,
    hyperlink, list, clear formatting
  * Position diagram boundary captions to top or bottom
  * Improve the odt template styles
  From Semantik 1.0.7:
  * Export rich text in html/s5 document generators
  * Add new styles for the odt template
  * Add text alignment options to diagram elements
  From Semantik 1.0.6:
  * Improve the document export from the command-line
  * Fix some annoying with the base directory changing to /tmp
  * Persist font settings in documents
  * Update the French translation data
  * Export png files in html and latex documents
  * Remove the Beamer files: most LaTeX distributions provide them nowadays
  From Semantik 1.0.5:
  * Highlight code snippets in beamer presentations/pdflatex using Minted
  * Fix drawing artifacts when switching diagrams
  * Fix the inactive custom color buttons in semantik #88
  * Add a color toolbar to semantik-d
  * Improve the default colors for readability
  From Semantik 1.0.4:
  * Improve PDF diagram export
  * Fix Qt Dbus compilation errors on some systems
  From Semantik 1.0.3:
  * Updated import filters to Python3 syntax #83
  * Fix image imports #84
  * Improve zigzag lines routing for sequence elements
  From Semantik 1.0.2:
  * Fix truncated saved documents in combination with accentuated characters
  * Deply highcolor icons to force the application icon
  * Deselect currently selected diagram elements after adding a new one
  * Add spell checking to the text widget
  * Improve paragraph handling for generated OpenOffice.org text documents
- added python3-Pygments BuildRequires
- use _service now
- removed semantik-filetree-qtdbus.patch
* Wed May  9 2018 bwiedemann@suse.com
- Use convert -strip to make package build reproducible (boo#1047218)
* Sat Apr 28 2018 i@marguerite.su
- add patch semantik-filetree-qtdbus.patch
  * Fix leap adn factory build.
    QDBusAbstractInterface not found
* Sat Dec  9 2017 fabian@ritter-vogt.de
- Update to 1.0.1:
  * Add a diagram sequence element
  * Fix improper pdf document dimensions
  * Fix the configuration and build on FreeBSD
  * Add installation notes for Fedora
- Update to 1.0.0:
  * Port to KDE5 and Python 3
  * Add SVG Export from the menus
  * Add new diagram shapes
  * Add resize handles to diagram objects
  * Add diagram link labels
* Tue Nov 29 2016 olaf@aepfle.de
- Expand macro kde4_runtime_requires only when its available
  to fix quilt setup
* Fri May 20 2016 olaf@aepfle.de
- Remove unused ocaml from Buildrequires
* Sun May 10 2015 lars@linux-schulserver.de
- update to 0.9.4
  * Resize class elements
  * Remember window settings in semantik-d
  * Minor linear view bug fixes
* Wed Nov 19 2014 i@marguerite.su
- update version 0.9.3
  * Generated HTML documents no longer reference pdf files
  * Save Semantik diagrams on exit
  * Minor changes in pdflatex documents
  * New class element in diagrams
  * Zoom improvements
- drop 0001-fix-ctrl-enter-crash.patch
  * upstream fixed
* Tue Oct  7 2014 oholecek@suse.com
- add 0001-fix-ctrl-enter-crash.patch: fix crash when adding new
  element
* Mon Sep 15 2014 i@marguerite.su
- update version 0.9.2
  * New diagram items: matrix, boundary, class
  * OpenOffice.org template fixes
  * Fix for null bytes inserted through copy-pasting
  * Removing an item from the linear view no longer causes an assertion
  * Build script fix for Python 3
* Wed Mar  5 2014 i@marguerite.su
- update version 0.9.1
  * Svg export
  * Odt template fixes
  * Include svg pictures in odt documents
  * command-line svg export
  * More reasonable size for the actors head
  * Prevent the memory corruption when opening the same recent file again
  * Make the text visible in the odt document created (Issue 27)
  * fixed the diagram top/bottom alignment function
  * Copy diagram pictures to clipboard from main window
  * Copy diagrams to the clipboard
* Mon Dec 23 2013 lars@linux-schulserver.de
- update to 0.9.0:
  * New application for editing and managing diagrams
  * Enhanced printing system from the menu
  * Print diagrams from the command-line
  * Fixed the jitter on the drawing area
* Wed Aug 28 2013 lars@linux-schulserver.de
- removed oxigen icons from spec to fix build
- added manpage for semantik commandline arguments
* Thu Aug  8 2013 i@marguerite.su
- update version 0.8.4
  * Export maps to pdf pictures from the command-line
  * Color scheme fixes #30
  * Null byte fix for text pasted from Chrome #26
* Mon Dec  3 2012 cfarrell@suse.com
- license update: GPL-3.0 and GPL-2.0
  See src/templates/beamer/beamermindist - most of the files there are
  GPL-2.0 (only). Looks like aggregation
* Mon Oct 22 2012 tnagy1024@gmail.com
- Update to version 0.8.3
  * New dialog for exporting the map as a picture with a specific size
  * More consistent gui elements (dialog buttons, menus)
  * New UML shapes
  * Straight arrows on the diagrams
  * Fixed several crashes
  * Fixe various LaTeX templates
  * New actor and usecase elements
* Sat Sep  8 2012 dmitry@roshchin.org
- Update to version 0.8.1
  * Made the gui mode-less
  * Enabled diagram, image and table export in the beamer template
  * Fixed the Java applet generator
  * undo/redo actions
  * select subtrees
* Mon Apr 27 2009 highwaystar.ru@gmail.com
- update to 0.7.2
- removed some unnecasary hacks from spec
* Wed Mar 19 2008 lars@linux-schulserver.de
- fix BuildRequires
- added rpmlintrc
* Tue Mar 18 2008 lars@linux-schulserver.de
- update to 0.6.6
* Fri Oct  5 2007 lars@linux-schulserver.de
- initial version 0.5.1
